import { z } from 'zod';
export declare const TypescriptPluginConfigSchema: z.ZodDefault<z.ZodAny>;
export type TypescriptPluginConfig = z.infer<typeof TypescriptPluginConfigSchema>;
export type TypescriptPluginInputConfig = z.input<typeof TypescriptPluginConfigSchema>;
export declare const ConfigSchema: z.ZodObject<z.objectUtil.extendShape<z.objectUtil.extendShape<{
    cloudformationTemplate: z.ZodString;
    schema: z.ZodUnion<[z.ZodString, z.ZodArray<z.ZodString, "many">]>;
    typescriptConfig: z.ZodDefault<z.ZodAny>;
    typescriptOutput: z.ZodString;
}, z.objectUtil.extendShape<{
    actionsModuleId: z.ZodString;
    dependenciesModuleId: z.ZodString;
    dispatcherDefaults: z.ZodDefault<z.ZodObject<z.objectUtil.extendShape<{
        memorySize: z.ZodDefault<z.ZodNumber>;
        timeout: z.ZodDefault<z.ZodNumber>;
    }, {
        batchSize: z.ZodDefault<z.ZodNumber>;
        maximumRetryAttempts: z.ZodDefault<z.ZodNumber>;
    }>, "strip", z.ZodTypeAny, {
        memorySize: number;
        timeout: number;
        batchSize: number;
        maximumRetryAttempts: number;
    }, {
        memorySize?: number | undefined;
        timeout?: number | undefined;
        batchSize?: number | undefined;
        maximumRetryAttempts?: number | undefined;
    }>>;
    handlerDefaults: z.ZodDefault<z.ZodObject<z.objectUtil.extendShape<{
        memorySize: z.ZodDefault<z.ZodNumber>;
        timeout: z.ZodDefault<z.ZodNumber>;
    }, {}>, "strip", z.ZodTypeAny, {
        memorySize: number;
        timeout: number;
    }, {
        memorySize?: number | undefined;
        timeout?: number | undefined;
    }>>;
    lambdaDefaults: z.ZodDefault<z.ZodObject<{
        memorySize: z.ZodDefault<z.ZodNumber>;
        timeout: z.ZodDefault<z.ZodNumber>;
    }, "strip", z.ZodTypeAny, {
        memorySize: number;
        timeout: number;
    }, {
        memorySize?: number | undefined;
        timeout?: number | undefined;
    }>>;
    requireExtensions: z.ZodDefault<z.ZodBoolean>;
    tableDefaults: z.ZodDefault<z.ZodObject<{
        enablePointInTimeRecovery: z.ZodDefault<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        enablePointInTimeRecovery: boolean;
    }, {
        enablePointInTimeRecovery?: boolean | undefined;
    }>>;
    useEfficientIndexes: z.ZodDefault<z.ZodBoolean>;
}, {
    actionsModuleId: z.ZodString;
    buildProperties: z.ZodDefault<z.ZodObject<{
        external: z.ZodDefault<z.ZodArray<z.ZodString, "many">>;
        minify: z.ZodDefault<z.ZodBoolean>;
        sourcemap: z.ZodDefault<z.ZodBoolean>;
        target: z.ZodDefault<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        external: string[];
        minify: boolean;
        sourcemap: boolean;
        target: string;
    }, {
        external?: string[] | undefined;
        minify?: boolean | undefined;
        sourcemap?: boolean | undefined;
        target?: string | undefined;
    }>>;
    cloudformationTransforms: z.ZodDefault<z.ZodArray<z.ZodString, "many">>;
    outputConfig: z.ZodDefault<z.ZodObject<{
        format: z.ZodDefault<z.ZodEnum<["json", "yaml"]>>;
        yamlConfig: z.ZodDefault<z.ZodObject<{
            condenseFlow: z.ZodOptional<z.ZodBoolean>;
            flowLevel: z.ZodOptional<z.ZodNumber>;
            forceQuotes: z.ZodDefault<z.ZodBoolean>;
            indent: z.ZodOptional<z.ZodNumber>;
            lineWidth: z.ZodOptional<z.ZodNumber>;
            noArrayIndent: z.ZodOptional<z.ZodBoolean>;
            noCompatMode: z.ZodOptional<z.ZodBoolean>;
            noRefs: z.ZodDefault<z.ZodBoolean>;
            quotingType: z.ZodDefault<z.ZodEnum<["'", "\""]>>;
            skipInvalid: z.ZodOptional<z.ZodBoolean>;
            sortKeys: z.ZodDefault<z.ZodBoolean>;
        }, "strip", z.ZodTypeAny, {
            forceQuotes: boolean;
            noRefs: boolean;
            quotingType: "'" | "\"";
            sortKeys: boolean;
            condenseFlow?: boolean | undefined;
            flowLevel?: number | undefined;
            indent?: number | undefined;
            lineWidth?: number | undefined;
            noArrayIndent?: boolean | undefined;
            noCompatMode?: boolean | undefined;
            skipInvalid?: boolean | undefined;
        }, {
            condenseFlow?: boolean | undefined;
            flowLevel?: number | undefined;
            forceQuotes?: boolean | undefined;
            indent?: number | undefined;
            lineWidth?: number | undefined;
            noArrayIndent?: boolean | undefined;
            noCompatMode?: boolean | undefined;
            noRefs?: boolean | undefined;
            quotingType?: "'" | "\"" | undefined;
            skipInvalid?: boolean | undefined;
            sortKeys?: boolean | undefined;
        }>>;
    }, "strip", z.ZodTypeAny, {
        format: "json" | "yaml";
        yamlConfig: {
            forceQuotes: boolean;
            noRefs: boolean;
            quotingType: "'" | "\"";
            sortKeys: boolean;
            condenseFlow?: boolean | undefined;
            flowLevel?: number | undefined;
            indent?: number | undefined;
            lineWidth?: number | undefined;
            noArrayIndent?: boolean | undefined;
            noCompatMode?: boolean | undefined;
            skipInvalid?: boolean | undefined;
        };
    }, {
        format?: "json" | "yaml" | undefined;
        yamlConfig?: {
            condenseFlow?: boolean | undefined;
            flowLevel?: number | undefined;
            forceQuotes?: boolean | undefined;
            indent?: number | undefined;
            lineWidth?: number | undefined;
            noArrayIndent?: boolean | undefined;
            noCompatMode?: boolean | undefined;
            noRefs?: boolean | undefined;
            quotingType?: "'" | "\"" | undefined;
            skipInvalid?: boolean | undefined;
            sortKeys?: boolean | undefined;
        } | undefined;
    }>>;
    singleQueueKey: z.ZodDefault<z.ZodBoolean>;
    sourceTemplate: z.ZodOptional<z.ZodString>;
}>>, z.objectUtil.extendShape<{
    actionsModuleId: z.ZodString;
    dependenciesModuleId: z.ZodString;
    dispatcherDefaults: z.ZodDefault<z.ZodObject<z.objectUtil.extendShape<{
        memorySize: z.ZodDefault<z.ZodNumber>;
        timeout: z.ZodDefault<z.ZodNumber>;
    }, {
        batchSize: z.ZodDefault<z.ZodNumber>;
        maximumRetryAttempts: z.ZodDefault<z.ZodNumber>;
    }>, "strip", z.ZodTypeAny, {
        memorySize: number;
        timeout: number;
        batchSize: number;
        maximumRetryAttempts: number;
    }, {
        memorySize?: number | undefined;
        timeout?: number | undefined;
        batchSize?: number | undefined;
        maximumRetryAttempts?: number | undefined;
    }>>;
    handlerDefaults: z.ZodDefault<z.ZodObject<z.objectUtil.extendShape<{
        memorySize: z.ZodDefault<z.ZodNumber>;
        timeout: z.ZodDefault<z.ZodNumber>;
    }, {}>, "strip", z.ZodTypeAny, {
        memorySize: number;
        timeout: number;
    }, {
        memorySize?: number | undefined;
        timeout?: number | undefined;
    }>>;
    lambdaDefaults: z.ZodDefault<z.ZodObject<{
        memorySize: z.ZodDefault<z.ZodNumber>;
        timeout: z.ZodDefault<z.ZodNumber>;
    }, "strip", z.ZodTypeAny, {
        memorySize: number;
        timeout: number;
    }, {
        memorySize?: number | undefined;
        timeout?: number | undefined;
    }>>;
    requireExtensions: z.ZodDefault<z.ZodBoolean>;
    tableDefaults: z.ZodDefault<z.ZodObject<{
        enablePointInTimeRecovery: z.ZodDefault<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        enablePointInTimeRecovery: boolean;
    }, {
        enablePointInTimeRecovery?: boolean | undefined;
    }>>;
    useEfficientIndexes: z.ZodDefault<z.ZodBoolean>;
}, {
    legacyEmptySortFieldBehavior: z.ZodDefault<z.ZodBoolean>;
}>>, "strip", z.ZodTypeAny, {
    schema: string | string[];
    actionsModuleId: string;
    dependenciesModuleId: string;
    dispatcherDefaults: {
        memorySize: number;
        timeout: number;
        batchSize: number;
        maximumRetryAttempts: number;
    };
    handlerDefaults: {
        memorySize: number;
        timeout: number;
    };
    lambdaDefaults: {
        memorySize: number;
        timeout: number;
    };
    requireExtensions: boolean;
    tableDefaults: {
        enablePointInTimeRecovery: boolean;
    };
    useEfficientIndexes: boolean;
    buildProperties: {
        external: string[];
        minify: boolean;
        sourcemap: boolean;
        target: string;
    };
    cloudformationTransforms: string[];
    outputConfig: {
        format: "json" | "yaml";
        yamlConfig: {
            forceQuotes: boolean;
            noRefs: boolean;
            quotingType: "'" | "\"";
            sortKeys: boolean;
            condenseFlow?: boolean | undefined;
            flowLevel?: number | undefined;
            indent?: number | undefined;
            lineWidth?: number | undefined;
            noArrayIndent?: boolean | undefined;
            noCompatMode?: boolean | undefined;
            skipInvalid?: boolean | undefined;
        };
    };
    singleQueueKey: boolean;
    legacyEmptySortFieldBehavior: boolean;
    cloudformationTemplate: string;
    typescriptOutput: string;
    sourceTemplate?: string | undefined;
    typescriptConfig?: any;
}, {
    schema: string | string[];
    actionsModuleId: string;
    dependenciesModuleId: string;
    cloudformationTemplate: string;
    typescriptOutput: string;
    dispatcherDefaults?: {
        memorySize?: number | undefined;
        timeout?: number | undefined;
        batchSize?: number | undefined;
        maximumRetryAttempts?: number | undefined;
    } | undefined;
    handlerDefaults?: {
        memorySize?: number | undefined;
        timeout?: number | undefined;
    } | undefined;
    lambdaDefaults?: {
        memorySize?: number | undefined;
        timeout?: number | undefined;
    } | undefined;
    requireExtensions?: boolean | undefined;
    tableDefaults?: {
        enablePointInTimeRecovery?: boolean | undefined;
    } | undefined;
    useEfficientIndexes?: boolean | undefined;
    buildProperties?: {
        external?: string[] | undefined;
        minify?: boolean | undefined;
        sourcemap?: boolean | undefined;
        target?: string | undefined;
    } | undefined;
    cloudformationTransforms?: string[] | undefined;
    outputConfig?: {
        format?: "json" | "yaml" | undefined;
        yamlConfig?: {
            condenseFlow?: boolean | undefined;
            flowLevel?: number | undefined;
            forceQuotes?: boolean | undefined;
            indent?: number | undefined;
            lineWidth?: number | undefined;
            noArrayIndent?: boolean | undefined;
            noCompatMode?: boolean | undefined;
            noRefs?: boolean | undefined;
            quotingType?: "'" | "\"" | undefined;
            skipInvalid?: boolean | undefined;
            sortKeys?: boolean | undefined;
        } | undefined;
    } | undefined;
    singleQueueKey?: boolean | undefined;
    sourceTemplate?: string | undefined;
    legacyEmptySortFieldBehavior?: boolean | undefined;
    typescriptConfig?: any;
}>;
export type Config = z.infer<typeof ConfigSchema>;
export type InputConfig = z.input<typeof ConfigSchema>;
//# sourceMappingURL=config.d.ts.map